import { animate, style, transition, trigger } from '@angular/animations';
import { Component, OnInit } from '@angular/core';
import { MatCardModule } from '@angular/material/card';
import { Notification, NotificationService } from '@core/notification/notification.service';

const NOTIFICATION_TTL = 3000;

@Component({
    selector: 'app-notification-box',
    imports: [MatCardModule],
    animations: [
        trigger('slideInOut', [
            transition(':enter', [
                style({ transform: 'translateX(100%)' }),
                animate('200ms ease-in-out', style({ transform: 'translateX(0)' })),
            ]),
            transition(':leave', [animate('200ms ease-in-out', style({ transform: 'translateX(100%)' })),])
        ]),
    ],
    templateUrl: './notification-box.component.html',
    styleUrl: './notification-box.component.scss'
})
export class NotificationBoxComponent implements OnInit {
    notifications: Map<number, Notification> = new Map();

    constructor(private notificationService: NotificationService) {
    }

    ngOnInit(): void {
        this.notificationService.subscribe('notification-box', this.onNotification.bind(this));
    }

    onNotification(notification: Notification): void {
        const now = Date.now();
        this.notifications.set(now, notification);

        setTimeout(() => {
            this.notifications.delete(now);
        }, NOTIFICATION_TTL);
    }
}
